@@ -407,6 +407,20 @@ case "Condizioni Generali di Contratto":  	$messaggio = "General Terms and Condi
 case "del servizio di memorizzazione delle carte di credito":	$messaggio = "of the credit cards storage service"; break;
 case "La password non è stata modificata":  	$messaggio = "The password has not been modified"; break;
 case "password errata":  			$messaggio = "wrong password"; break;
+case "adulto":  				$messaggio = "adult"; break;
+case "adulti":  				$messaggio = "adults"; break;
+case "bambino":  				$messaggio = "child"; break;
+case "bambini":  				$messaggio = "children"; break;
+case "Numero di categorie delle persone":  	$messaggio = "Number of people categories"; break;
+case "Categoria":  				$messaggio = "Category"; break;
+case "Può essere ospite principale":  		$messaggio = "Can be main guest"; break;
+case "Prezzo in percentuale del prezzo per persona":	$messaggio = "Price in percentage of per person price"; break;
+case "arrotondato a":  				$messaggio = "rounded to"; break;
+case "Modifica le categorie delle persone":  	$messaggio = "Modify people categories"; break;
+case "Il numero di categorie delle persone è sbagliato":	$messaggio = "The number of people categories is wrong"; break;
+case "Il numero di categorie delle persone è stato cambiato":	$messaggio = "The number of people categories has been changed"; break;
+case "I dati inseriti non sono corretti":  	$messaggio = "Inserted data are incorrect"; break;
+case "Le categorie delle persone sono state modificate":	$messaggio = "The people categories have been modified"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
