@@ -95,6 +95,10 @@ $trad_var['valore_costo_agg_senza_tasse'] = 'extra_cost_value_without_taxes';
 $trad_var['valore_costo_agg_senza_tasse_p'] = 'extra_cost_value_without_taxes_p';
 $trad_var['moltiplica_max_costo_agg'] = 'extra_cost_max_multiply';
 $trad_var['moltiplica_max_costo_agg_sel'] = 'sel_extra_cost_max_multiply';
+$trad_var['valore_giornaliero_max_costo_agg'] = 'extra_cost_max_daily_value';
+$trad_var['valore_giornaliero_max_costo_agg_p'] = 'extra_cost_max_daily_value_p';
+$trad_var['valore_giornaliero_max_costo_agg_sel'] = 'sel_extra_cost_max_daily_value';
+$trad_var['valore_giornaliero_max_costo_agg_sel_p'] = 'sel_extra_cost_max_daily_value_p';
 $trad_var['data_inserimento_costo_agg'] = 'extra_cost_insertion_date';
 $trad_var['utente_inserimento_costo_agg'] = 'extra_cost_insertion_user';
 $trad_var['percentuale_tasse_costo_agg_sel'] = 'sel_extra_cost_taxes_percentage';
