@@ -407,6 +407,20 @@ case "Condizioni Generali di Contratto":  	$messaggio = "Condiciones Generales d
 case "del servizio di memorizzazione delle carte di credito":	$messaggio = "del servicio de almacenamiento de tarjetas de crédito"; break;
 case "La password non è stata modificata":  	$messaggio = "La contraseña no ha sido modificada"; break;
 case "password errata":  			$messaggio = "contraseña equivocada"; break;
+case "adulto":  				$messaggio = "adulto"; break;
+case "adulti":  				$messaggio = "adultos"; break;
+case "bambino":  				$messaggio = "niño"; break;
+case "bambini":  				$messaggio = "niños"; break;
+case "Numero di categorie delle persone":  	$messaggio = "Número de categorías de personas"; break;
+case "Categoria":  				$messaggio = "Categoría"; break;
+case "Può essere ospite principale":  		$messaggio = "Puede ser huésped principal"; break;
+case "Prezzo in percentuale del prezzo per persona":	$messaggio = "Precio en porcentaje del precio por persona"; break;
+case "arrotondato a":  				$messaggio = "redondeado a"; break;
+case "Modifica le categorie delle persone":  	$messaggio = "Modificar las categorías de personas"; break;
+case "Il numero di categorie delle persone è sbagliato":	$messaggio = "El número de categorías de personas está equivocado"; break;
+case "Il numero di categorie delle persone è stato cambiato":	$messaggio = "El número de categorías de personas ha sido cambiado"; break;
+case "I dati inseriti non sono corretti":  	$messaggio = "Los datos insertados no son correctos"; break;
+case "Le categorie delle persone sono state modificate":	$messaggio = "Las categorías de personas han sido modificadas"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
