@@ -352,6 +352,19 @@ case "non potrà più modificare i <b>documenti come API</b>":	$messaggio = "ya
 case "Gestione della password per le carte di credito":	$messaggio = "Gestión de la contraseña para las tarjetas de crédito"; break;
 case "potrà gestire la <b>password per le carte di credito</b>":	$messaggio = "podrá gestionar la <b>contraseña para las tarjetas de crédito</b>"; break;
 case "non potrà più gestire la <b>password per le carte di credito</b>":	$messaggio = "ya no podrá gestionar la <b>contraseña para las tarjetas de crédito</b>"; break;
+case "senza mostrare il valore":  		$messaggio = "sin mostrar el valor"; break;
+case "mostrando il valore":  			$messaggio = "mostrando el valor"; break;
+case "senza mostrare i valori":  		$messaggio = "sin mostrar los valores"; break;
+case "mostrando i valori":  			$messaggio = "mostrando los valores"; break;
+case "Possibilità di modificare l'utente che ha inserito":	$messaggio = "Posibilidad de modificar el usuario que ha insertado"; break;
+case "con tutti gli utenti":  			$messaggio = "con todos los usuarios"; break;
+case "solo con utenti dei suoi gruppi":  	$messaggio = "solo con los usuarios de sus grupos"; break;
+case "mostrando l'utente":  			$messaggio = "mostrando el usuario"; break;
+case "senza mostrare l'utente":  		$messaggio = "sin mostrar el usuario"; break;
+case "potrà modificare l'<b>utente</b> che ha inserito la prenotazione nel":	$messaggio = "podrá modificar el <b>usuario</b> que ha insertado la reserva en el"; break;
+case "non potrà modificare l'<b>utente</b> che ha inserito la prenotazione nel":	$messaggio = "ya no podrá modificar el <b>usuario</b> que ha insertado la reserva en el"; break;
+case "senza mostrarla":  			$messaggio = "sin mostrarla"; break;
+case "senza mostrarli":  			$messaggio = "sin mostrarlos"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
