@@ -64,7 +64,7 @@ $id_utente_azione_ic = "a";
 include(C_DATI_PATH."/lingua.php");
 $lingua_mex = $lingua[1];
 if (defined('C_URL_MOD_EXT_CARTE_CREDITO') and C_URL_MOD_EXT_CARTE_CREDITO != "") {
-$id_utente = "-1";
+$id_utente_sessione = "-1";
 $adesso = $anno.date("mdHis",(time() + (C_DIFF_ORE * 3600)));
 $versione_unica = prendi_numero_versione($tableversioni);
 list($usec, $sec) = explode(' ', microtime());
@@ -80,7 +80,7 @@ if ($_SERVER['HTTP_USER_AGENT']) $HTTP_USER_AGENT = $_SERVER['HTTP_USER_AGENT'];
 $HTTP_USER_AGENT = aggslashdb($HTTP_USER_AGENT);
 if ($_SERVER['HTTPS'] == "on" or $_SERVER['SERVER_PORT'] == "443") $tipo_conn = "HTTPS";
 else $tipo_conn = "HTTP";
-esegui_query("insert into $tablesessioni (idsessioni,idutente,indirizzo_ip,tipo_conn,user_agent,ultimo_accesso) values ('$id_sessione','$id_utente','$REMOTE_ADDR','$tipo_conn','$HTTP_USER_AGENT','$ultimo_accesso')");
+esegui_query("insert into $tablesessioni (idsessioni,idutente,indirizzo_ip,tipo_conn,user_agent,ultimo_accesso) values ('$id_sessione','$id_utente_sessione','$REMOTE_ADDR','$tipo_conn','$HTTP_USER_AGENT','$ultimo_accesso')","",1);
 } # fine if (defined('C_URL_MOD_EXT_CARTE_CREDITO') and C_URL_MOD_EXT_CARTE_CREDITO != "")
 #} # fine if (!numlin_query($id_utente_az))
 } # fine if (defined("C_UTENTE_AZIONE_IC") and C_UTENTE_AZIONE_IC != "" and $utente_azione_ic == C_UTENTE_AZIONE_IC)
@@ -108,7 +108,7 @@ $id_utente_az = esegui_query("select idlocale from $tableinterconnessioni where
 if (numlin_query($id_utente_az) == 1) $id_utente_azione_ic = risul_query($id_utente_az,0,'idlocale');
 } # fine if ($id_utente and ($priv_crea_interconnessioni != "s" or $anno_utente_attivato != "SI") and !$id_utente_azione_ic)
 
-if ($id_utente and (($priv_crea_interconnessioni == "s" and $anno_utente_attivato == "SI") or $id_utente == $id_utente_azione_ic) and C_CREA_SUBORDINAZIONI != "NO") {
+if ($id_utente and (($priv_crea_interconnessioni == "s" and $anno_utente_attivato == "SI") or $id_utente == $id_utente_azione_ic) and (!defined('C_CREA_SUBORDINAZIONI') or C_CREA_SUBORDINAZIONI != "NO")) {
 
 if (@is_file(C_DATI_PATH."/dati_subordinazione.php")) {
 $installazione_subordinata = "SI";
@@ -527,7 +527,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./interconnessioni
 } # fine if (@is_file(C_DATI_PATH."/dati_subordinazione.php"))
 else {
 
-if (C_NASCONDI_MARCA == "SI") echo "<div style=\"text-align: center;\"><b>".mex("Crea la subordinazione",$pag)."</b></div><br>";
+if (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA == "SI") echo "<div style=\"text-align: center;\"><b>".mex("Crea la subordinazione",$pag)."</b></div><br>";
 else echo "<div style=\"text-align: center;\"><b>".mex("Subordinazione ad un'altra installazione di hoteldruid",$pag)."</b></div><br>";
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./interconnessioni.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -535,7 +535,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./interconnessioni
 <input type=\"hidden\" name=\"modifica_interconnessione\" value=\"SI\">
 <div style=\"line-height: 1.3;\">
 ".mex("Con la subordinazione non si potranno inserire nuovi dati o apportare modifiche, ma solo importare i dati dall'installazione principale",$pag).".<br>";
-if (C_NASCONDI_MARCA == "SI") echo str_replace("hoteldruid","",mex("Subordina questa installazione di hoteldruid a quella che si trova all'indirizzo",$pag)).":<br>";
+if (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA == "SI") echo str_replace("hoteldruid","",mex("Subordina questa installazione di hoteldruid a quella che si trova all'indirizzo",$pag)).":<br>";
 else echo mex("Subordina questa installazione di hoteldruid a quella che si trova all'indirizzo",$pag).":<br>";
 echo "<input type=\"text\" name=\"url_subordinazione\" value=\"http://\" size=60><br>
 ".ucfirst(mex("amministratore o utente con i privilegi per creare backup",$pag)).":<br>
@@ -560,13 +560,13 @@ if ($mod_ext != "." and $mod_ext != ".." and @is_dir("./includes/interconnect/$m
 } # fine while ($mod_ext = readdir($interconn_dir))
 ksort($interconnessioni);
 reset($interconnessioni);
-while (list($mod_ext,$val_i) = each($interconnessioni)) {
+foreach ($interconnessioni as $mod_ext => $val_i) {
 include("./includes/interconnect/$mod_ext/name.php");
 if ($interconnection_name_show[$lingua_mex]) $titolo = $interconnection_name_show[$lingua_mex];
 else $titolo = $interconnection_name_show['en'];
-echo "<hr style=\"width: 95%\"><div style=\"text-align: center;\"><b>$titolo</b></div><br>";
+echo "<hr style=\"width: 95%\"><div id=\"h$interconnection_data_dir\" style=\"text-align: center;\"><b>$titolo</b></div><br>";
 include("./includes/interconnect/$mod_ext/form.php");
-} # fine while (list($mod_ext,$val_i) = each($interconnessioni))
+} # fine foreach ($interconnessioni as $mod_ext => $val_i)
 closedir($interconn_dir);
 
 
@@ -577,7 +577,7 @@ if ($modello_ext != "." and $modello_ext != ".." and @is_dir("./includes/templat
 } # fine while ($file = readdir($lang_dig))
 ksort($modelli);
 reset($modelli);
-while (list($modello_ext,$val_i) = each($modelli)) {
+foreach ($modelli as $modello_ext => $val_i) {
 include("./includes/templates/$modello_ext/name.php");
 if ($template_name_show['tpl_type'] == "interconnection") {
 if (!function_exists('mex2')) {
@@ -598,10 +598,10 @@ if ($messaggio == $template_name_show['ita']) $messaggio = "";
 if ($messaggio) $titolo = $messaggio;
 else $titolo = $template_name_show['en'];
 } # fine else if ($template_name_show[$lingua_mex])
-echo "<hr style=\"width: 95%\"><div style=\"text-align: center;\"><b>$titolo</b></div><br>";
+echo "<hr style=\"width: 95%\"><div id=\"h".$modello_ext."\" style=\"text-align: center;\"><b>$titolo</b></div><br>";
 include("./includes/templates/$modello_ext/form.php");
 } # fine if ($template_name_show['tpl_type'] == "interconnection")
-} # fine while (list($modello_ext,$val_i) = each($modelli))
+} # fine foreach ($modelli as $modello_ext => $val_i)
 closedir($templates_dir);
 
 
@@ -622,7 +622,7 @@ if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$t
 else include("./includes/foot.php");
 
 
-} # fine if ($id_utente and (($priv_crea_interconnessioni == "s" and $anno_utente_attivato == "SI") or $id_utente == $id_utente_azione_ic) and C_CREA_SUBORDINAZIONI != "NO")
+} # fine if ($id_utente and (($priv_crea_interconnessioni == "s" and $anno_utente_attivato == "SI") or $id_utente == $id_utente_azione_ic) and (!defined('C_CREA_SUBORDINAZIONI') or C_CREA_SUBORDINAZIONI != "NO"))
 
 
 
